==> paycenter-client-3.3.73.12-20220322.115040-1-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/ningbobank/notify/NbcbOrderNotifyRequestDto.java <==
package cn.com.duiba.paycenter.dto.payment.charge.ningbobank.notify;

import java.io.Serializable;

/**
 * @author fja
 */
public class NbcbOrderNotifyRequestDto {
    /**
     * 商户系统编号
     */
    private String platformId;
    /**
     * 商户交易流水号
     */
    private String merSeqNo;

    /**
     * 支付网关系统交易流水号
     */
    private String transSeqNo;

    /**
     * 清算日期
     */
    private String clearDate;

    /**
     * 交易金额
     */
    private String transAmt;

    /**
     * 00-交易成功、01-交易失败、99-交易超时
     */
    private String status;

    /**
     * 响应信息
     */
    private String respMsg;


    private String transId;


    public String getPlatformId() {
        return platformId;
    }

    public void setPlatformId(String platformId) {
        this.platformId = platformId;
    }

    public String getMerSeqNo() {
        return merSeqNo;
    }

    public void setMerSeqNo(String merSeqNo) {
        this.merSeqNo = merSeqNo;
    }

    public String getTransSeqNo() {
        return transSeqNo;
    }

    public void setTransSeqNo(String transSeqNo) {
        this.transSeqNo = transSeqNo;
    }

    public String getClearDate() {
        return clearDate;
    }

    public void setClearDate(String clearDate) {
        this.clearDate = clearDate;
    }

    public String getTransAmt() {
        return transAmt;
    }

    public void setTransAmt(String transAmt) {
        this.transAmt = transAmt;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getRespMsg() {
        return respMsg;
    }

    public void setRespMsg(String respMsg) {
        this.respMsg = respMsg;
    }

    public String getTransId() {
        return transId;
    }

    public void setTransId(String transId) {
        this.transId = transId;
    }
}

==> paycenter-client-3.5.35-20250915.094345-1-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/ningbobank/notify/NbcbOrderNotifyRequestDto.java <==
package cn.com.duiba.paycenter.dto.payment.charge.ningbobank.notify;

import java.io.Serializable;

/**
 * @author fja
 * {"Status":"00","clearDate":"2022-03-29","transSeqNo":"20220329193822535987","transId":"IPER","transAmt":0.01,"merSeqNo":"194057776862652C0538","respMsg":null,"notifyUrl":"http://activity.m.duibatest.com.cn/taw/nbcb/payNotify","platformId":null}
 */
public class NbcbOrderNotifyRequestDto implements Serializable{
    /**
     * 商户系统编号
     */
    private String platformId;
    /**
     * 商户交易流水号
     */
    private String merSeqNo;

    /**
     * 支付网关系统交易流水号
     */
    private String transSeqNo;

    /**
     * 清算日期
     */
    private String clearDate;

    /**
     * 交易金额
     */
    private Double transAmt;

    /**
     * 00-交易成功、01-交易失败、99-交易超时
     */
    private String status;

    /**
     * 响应信息
     */
    private String respMsg;


    private String transId;


    public String getPlatformId() {
        return platformId;
    }

    public void setPlatformId(String platformId) {
        this.platformId = platformId;
    }

    public String getMerSeqNo() {
        return merSeqNo;
    }

    public void setMerSeqNo(String merSeqNo) {
        this.merSeqNo = merSeqNo;
    }

    public String getTransSeqNo() {
        return transSeqNo;
    }

    public void setTransSeqNo(String transSeqNo) {
        this.transSeqNo = transSeqNo;
    }

    public String getClearDate() {
        return clearDate;
    }

    public void setClearDate(String clearDate) {
        this.clearDate = clearDate;
    }

    public Double getTransAmt() {
        return transAmt;
    }

    public void setTransAmt(Double transAmt) {
        this.transAmt = transAmt;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getRespMsg() {
        return respMsg;
    }

    public void setRespMsg(String respMsg) {
        this.respMsg = respMsg;
    }

    public String getTransId() {
        return transId;
    }

    public void setTransId(String transId) {
        this.transId = transId;
    }
}
